@@ -1,22 +1,8 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * Copyright (C) 2014  Christian Mollekopf <mollekopf@kolabsys.com>
+ * SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
  */
 #include <scheduler.h>
@@ -191,7 +177,7 @@ private Q_SLOTS:
 
         QSharedPointer<DummyJobFactory> factory(new DummyJobFactory());
         Scheduler scheduler(index, config, factory);
-        QSignalSpy statusSpy(&scheduler, SIGNAL(status(int,QString)));
+        QSignalSpy statusSpy(&scheduler, &Scheduler::status);
         QSignalSpy finishedIndexing(&scheduler, &Scheduler::collectionIndexingFinished);
 
         scheduler.setBusyTimeout(0);
