@@ -8,7 +8,6 @@
 
 #include "term.h"
 
-#include <QVariant>
 #include <QDateTime>
 
 using namespace Akonadi::Search;
@@ -16,23 +15,16 @@ using namespace Akonadi::Search;
 class Q_DECL_HIDDEN Akonadi::Search::Term::Private
 {
 public:
-    Operation m_op;
-    Comparator m_comp;
+    Operation m_op = None;
+    Comparator m_comp = Auto;
 
     QString m_property;
     QVariant m_value;
 
-    bool m_isNegated;
+    bool m_isNegated = false;
 
     QList<Term> m_subTerms;
     QVariantHash m_userData;
-
-    Private()
-    {
-        m_op = None;
-        m_comp = Auto;
-        m_isNegated = false;
-    }
 };
 
 Term::Term()
