@@ -24,11 +24,6 @@ using namespace Akonadi::Search;
 class Akonadi::Search::AkonadiSearchDebugDialogPrivate
 {
 public:
-    AkonadiSearchDebugDialogPrivate()
-        : mAkonadiSearchDebugWidget(nullptr)
-    {
-    }
-
     AkonadiSearchDebugWidget *mAkonadiSearchDebugWidget = nullptr;
 };
 
@@ -39,9 +34,9 @@ AkonadiSearchDebugDialog::AkonadiSearchDebugDialog(QWidget *parent)
     //Don't translate it's just a dialog to debug
     setWindowTitle(QStringLiteral("Debug Akonadi Search"));
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    QPushButton *user1Button = new QPushButton;
+    auto *user1Button = new QPushButton;
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     //Don't translate it.
     user1Button->setText(QStringLiteral("Save As..."));
