@@ -1,7 +1,7 @@
 /*
   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  SPDX-License-Identifier: GPL-2.0-only
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "akonadisearchdebugdialogtest.h"
@@ -29,11 +29,11 @@ void AkonadiSearchDebugDialogTest::initTestCase()
 void AkonadiSearchDebugDialogTest::shouldHaveDefaultValue()
 {
     Akonadi::Search::AkonadiSearchDebugDialog dlg;
-    Akonadi::Search::AkonadiSearchDebugWidget *debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
+    auto *debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
     QVERIFY(debugWidget);
-    QPlainTextEdit *editorWidget = debugWidget->findChild<QPlainTextEdit *>(QStringLiteral("plaintexteditor"));
+    auto *editorWidget = debugWidget->findChild<QPlainTextEdit *>(QStringLiteral("plaintexteditor"));
     QVERIFY(editorWidget);
-    KLineEdit *lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
+    auto *lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
     QVERIFY(lineEdit);
     QVERIFY(lineEdit->text().isEmpty());
 }
@@ -41,9 +41,9 @@ void AkonadiSearchDebugDialogTest::shouldHaveDefaultValue()
 void AkonadiSearchDebugDialogTest::shouldFillLineEditWhenWeWantToSearchItem()
 {
     Akonadi::Search::AkonadiSearchDebugDialog dlg;
-    Akonadi::Search::AkonadiSearchDebugWidget *debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
+    auto *debugWidget = dlg.findChild<Akonadi::Search::AkonadiSearchDebugWidget *>(QStringLiteral("akonadisearchdebugwidget"));
     QVERIFY(debugWidget);
-    KLineEdit *lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
+    auto *lineEdit = debugWidget->findChild<KLineEdit *>(QStringLiteral("lineedit"));
     QVERIFY(lineEdit);
     const int value = 42;
     const QString akonadiItem = QString::number(value);
